@@ -14,6 +14,7 @@ import psutil
 from importlib import import_module
 from numbers import Number
 from concurrent.futures import as_completed
+from warnings import warn
 
 from reV.config.project_points import ProjectPoints
 from reV.generation.generation import Gen
@@ -24,7 +25,6 @@ from reV.handlers.exclusions import ExclusionLayers
 from reV.supply_curve.extent import SupplyCurveExtent
 from reV.supply_curve.points import AggregationSupplyCurvePoint as AggSCPoint
 from reV.supply_curve.aggregation import AbstractAggregation, AggFileHandler
-from reV.losses import PowerCurveLossesMixin, ScheduledLossesMixin
 from reV.utilities.exceptions import (EmptySupplyCurvePointError,
                                       FileInputError)
 from reV.utilities import log_versions
@@ -56,7 +56,7 @@ class BespokeSinglePlant:
                  ws_bins=(0.0, 20.0, 5.0), wd_bins=(0.0, 360.0, 45.0),
                  excl_dict=None, inclusion_mask=None, data_layers=None,
                  resolution=64, excl_area=None, exclusion_shape=None,
-                 close=True):
+                 eos_mult_baseline_cap_mw=200, close=True):
         """
         Parameters
         ----------
@@ -155,6 +155,13 @@ class BespokeSinglePlant:
         exclusion_shape : tuple
             Shape of the full exclusions extent (rows, cols). Inputing this
             will speed things up considerably.
+        eos_mult_baseline_cap_mw : int | float, optional
+            Baseline plant capacity (MW) used to calculate economies of
+            scale (EOS) multiplier from the `capital_cost_function`. EOS
+            multiplier is calculated as the $-per-kW of the wind plant
+            divided by the $-per-kW of a plant with this baseline
+            capacity. By default, `200` (MW), which aligns the baseline
+            with ATB assumptions. See here: https://tinyurl.com/y85hnu6h.
         close : bool
             Flag to close object file handlers on exit.
         """
@@ -196,6 +203,7 @@ class BespokeSinglePlant:
         self._out_req = list(output_request)
         self._ws_bins = ws_bins
         self._wd_bins = wd_bins
+        self._baseline_cap_mw = eos_mult_baseline_cap_mw
 
         self._res_df = None
         self._meta = None
@@ -371,22 +379,13 @@ class BespokeSinglePlant:
         -------
         dict
         """
+        config = copy.deepcopy(self._sam_sys_inputs)
         if self._wind_plant_pd is None:
-            return copy.deepcopy(self._sam_sys_inputs)
-        else:
-            config = copy.deepcopy(self._wind_plant_pd.sam_sys_inputs)
-            config['wind_turbine_powercurve_powerout'] = \
-                self._sam_sys_inputs['wind_turbine_powercurve_powerout']
-
-            keys_to_copy = [PowerCurveLossesMixin.POWER_CURVE_CONFIG_KEY,
-                            ScheduledLossesMixin.OUTAGE_CONFIG_KEY,
-                            'hourly']
-            for key in keys_to_copy:
-                if key in self._sam_sys_inputs:
-                    config[key] = self._sam_sys_inputs[key]
-
             return config
 
+        config.update(self._wind_plant_pd.sam_sys_inputs)
+        return config
+
     @property
     def sc_point(self):
         """Get the reV supply curve point object.
@@ -844,6 +843,15 @@ class BespokeSinglePlant:
         # convert SAM system capacity in kW to reV supply curve cap in MW
         self._meta['capacity'] = self.outputs['system_capacity'] / 1e3
 
+        # add required ReEDS multipliers to meta
+        baseline_cost = self.plant_optimizer.capital_cost_per_kw(
+            capacity_mw=self._baseline_cap_mw)
+        self._meta['eos_mult'] = (self.plant_optimizer.capital_cost
+                                  / self.plant_optimizer.capacity
+                                  / baseline_cost)
+        self._meta['reg_mult'] = (self.sam_sys_inputs
+                                  .get("capital_cost_multiplier", 1))
+
         return self.outputs
 
     def agg_data_layers(self):
@@ -927,12 +935,23 @@ class BespokeWindPlants(AbstractAggregation):
             Dataset name in the techmap file containing the
             exclusions-to-resource mapping data.
         points : int | slice | list | str | PointsControl | None
-            Slice or list specifying project points, string pointing to a
-            project points csv, or a fully instantiated PointsControl object.
-            Can also be a single site integer value. Points csv should have
-            'gid' and 'config' column, the config maps to the sam_configs dict
-            keys. If this is None, all available reV supply curve points are
-            included (or sliced by points_range).
+            Slice or list specifying project points, string pointing to
+            a project points csv, or a fully instantiated PointsControl
+            object. Can also be a single site integer value. Points csv
+            should have 'gid' and 'config' column, the config maps to
+            the sam_configs dict keys. CSV file can also have any of the
+            SAM system config keys as columns. Values of these columns
+            are treated as site-specific inputs for each gid. CSV file
+            can also have these extra columns:
+                - capital_cost_multiplier
+                - fixed_operating_cost_multiplier
+                - variable_operating_cost_multiplier
+            These inputs are treated as multipliers to be applied to
+            the respective cost curves (`capital_cost_function`,
+            `fixed_operating_cost_function`, and
+            `variable_operating_cost_function`) both during and after
+            the optimization. If this is None, all available reV supply
+            curve points are included (or sliced by points_range).
         sam_configs : dict | str | SAMConfig
             SAM input configuration ID(s) and file path(s). Keys are the SAM
             config ID(s) which map to the config column in the project points
@@ -1216,6 +1235,33 @@ class BespokeWindPlants(AbstractAggregation):
             meta = meta[0]
         return meta
 
+    def sam_sys_inputs_with_site_data(self, gid):
+        """Update the sam_sys_inputs with site data for the given GID.
+
+        Site data is extracted from the project points DataFrame. Every
+        column in the project DataFrame becomes a key in the site_data
+        output dictionary.
+
+        Parameters
+        ----------
+        gid : int
+            SC point gid for site to pull site data for.
+
+        Returns
+        -------
+        dictionary : dict
+            SAM system config with extra keys from the project points
+            DataFrame.
+        """
+
+        gid_idx = self._project_points.index(gid)
+        site_data = self._project_points.df.iloc[gid_idx]
+
+        site_sys_inputs = self._project_points[gid][1]
+        site_sys_inputs.update({k: v for k, v in site_data.to_dict().items()
+                                if not (isinstance(v, float) and np.isnan(v))})
+        return site_sys_inputs
+
     def _init_fout(self, out_fpath, sample):
         """Initialize the bespoke output h5 file with meta and time index dsets
 
@@ -1312,6 +1358,12 @@ class BespokeWindPlants(AbstractAggregation):
             Full filepath to an output .h5 file to save Bespoke data to. The
             parent directories will be created if they do not already exist.
         """
+        if not self.completed_gids:
+            msg = ("No output data found! It is likely that all requested "
+                   "points are excluded.")
+            logger.warning(msg)
+            warn(msg)
+            return
 
         sample = self.outputs[self.completed_gids[0]]
         out_fpath = self._init_fout(out_fpath, sample)
@@ -1486,7 +1538,7 @@ class BespokeWindPlants(AbstractAggregation):
                     self._excl_fpath,
                     self._res_fpath,
                     self._tm_dset,
-                    self._project_points[gid][1],
+                    self.sam_sys_inputs_with_site_data(gid),
                     self._obj_fun,
                     self._cap_cost_fun,
                     self._foc_fun,
@@ -1570,7 +1622,7 @@ class BespokeWindPlants(AbstractAggregation):
         if max_workers == 1:
             for gid in bsp.gids:
                 si = bsp.run_serial(excl_fpath, res_fpath, tm_dset,
-                                    bsp._project_points[gid][1],
+                                    bsp.sam_sys_inputs_with_site_data(gid),
                                     objective_function,
                                     capital_cost_function,
                                     fixed_operating_cost_function,
