@@ -25,6 +25,7 @@ from reV.SAM.generation import (PvWattsv5,
 
 from rex.resource import Resource
 from rex.multi_file_resource import MultiFileResource
+from rex.multi_res_resource import MultiResolutionResource
 from rex.utilities.utilities import check_res_file
 
 logger = logging.getLogger(__name__)
@@ -111,9 +112,10 @@ class Gen(BaseGen):
     OUT_ATTRS.update(TPPH_ATTRS)
     OUT_ATTRS.update(BaseGen.ECON_ATTRS)
 
-    def __init__(self, points_control, res_file, output_request=('cf_mean',),
-                 site_data=None, gid_map=None, out_fpath=None, drop_leap=False,
-                 mem_util_lim=0.4, scale_outputs=True):
+    def __init__(self, points_control, res_file, lr_res_file=None,
+                 output_request=('cf_mean',), site_data=None, gid_map=None,
+                 out_fpath=None, drop_leap=False, mem_util_lim=0.4,
+                 scale_outputs=True, write_mapped_gids=False):
         """
         Parameters
         ----------
@@ -122,6 +124,12 @@ class Gen(BaseGen):
         res_file : str
             Filepath to single resource file, multi-h5 directory,
             or /h5_dir/prefix*suffix
+        lr_res_file : str | None
+            Optional low resolution resource file that will be dynamically
+            mapped+interpolated to the nominal-resolution res_file. This
+            needs to be of the same format as resource_file, e.g. they both
+            need to be handled by the same rex Resource handler such as
+            WindResource
         output_request : list | tuple
             Output variables requested from SAM.
         site_data : str | pd.DataFrame | None
@@ -147,6 +155,9 @@ class Gen(BaseGen):
             to disk.
         scale_outputs : bool
             Flag to scale outputs in-place immediately upon Gen returning data.
+        write_mapped_gids : bool
+            Option to write mapped gids to output meta instead of resource
+            gids.
         """
 
         super().__init__(points_control, output_request, site_data=site_data,
@@ -162,13 +173,16 @@ class Gen(BaseGen):
             logger.error(msg)
             raise KeyError(msg)
 
+        self.write_mapped_gids = write_mapped_gids
         self._res_file = res_file
+        self._lr_res_file = lr_res_file
         self._sam_module = self.OPTIONS[self.tech]
         self._run_attrs['sam_module'] = self._sam_module.MODULE
         self._run_attrs['res_file'] = res_file
 
         self._multi_h5_res, self._hsds = check_res_file(res_file)
         self._gid_map = self._parse_gid_map(gid_map)
+        self._nn_map = self._parse_nn_map()
 
         # initialize output file
         self._init_fpath()
@@ -187,6 +201,16 @@ class Gen(BaseGen):
         """
         return self._res_file
 
+    @property
+    def lr_res_file(self):
+        """Get the (optional) low-resolution resource filename and path.
+
+        Returns
+        -------
+        str | None
+        """
+        return self._lr_res_file
+
     @property
     def meta(self):
         """Get resource meta for all sites in project points.
@@ -225,6 +249,8 @@ class Gen(BaseGen):
                 self._meta = res['meta', res_gids]
 
             self._meta.loc[:, 'gid'] = res_gids
+            if self.write_mapped_gids:
+                self._meta.loc[:, 'gid'] = self.project_points.sites
             self._meta.index = self.project_points.sites
             self._meta.index.name = 'gid'
             self._meta.loc[:, 'reV_tech'] = self.project_points.tech
@@ -271,8 +297,9 @@ class Gen(BaseGen):
         return self._time_index
 
     @classmethod
-    def run(cls, points_control, tech=None, res_file=None, output_request=None,
-            scale_outputs=True, gid_map=None):
+    def run(cls, points_control, tech=None, res_file=None, lr_res_file=None,
+            output_request=None, scale_outputs=True, gid_map=None,
+            nn_map=None):
         """Run a SAM generation analysis based on the points_control iterator.
 
         Parameters
@@ -286,6 +313,12 @@ class Gen(BaseGen):
         res_file : str
             Filepath to single resource file, multi-h5 directory,
             or /h5_dir/prefix*suffix
+        lr_res_file : str | None
+            Optional low resolution resource file that will be dynamically
+            mapped+interpolated to the nominal-resolution res_file. This
+            needs to be of the same format as resource_file, e.g. they both
+            need to be handled by the same rex Resource handler such as
+            WindResource
         output_request : list | tuple
             Output variables requested from SAM.
         scale_outputs : bool
@@ -295,6 +328,10 @@ class Gen(BaseGen):
             resource gids (values). This enables the user to input unique
             generation gids in the project points that map to non-unique
             resource gids. This can be None or a pre-extracted dict.
+        nn_map : np.ndarray
+            Optional 1D array of nearest neighbor mappings associated with the
+            res_file to lr_res_file spatial mapping. For details on this
+            argument, see the rex.MultiResolutionResource docstring.
 
         Returns
         -------
@@ -309,9 +346,12 @@ class Gen(BaseGen):
 
         # run generation method for specified technology
         try:
-            out = cls.OPTIONS[tech].reV_run(points_control, res_file, site_df,
-                                            output_request=output_request,
-                                            gid_map=gid_map)
+            out = cls.OPTIONS[tech].reV_run(
+                points_control, res_file, site_df,
+                lr_res_file=lr_res_file,
+                output_request=output_request,
+                gid_map=gid_map, nn_map=nn_map)
+
         except Exception as e:
             out = {}
             logger.exception('Worker failed for PC: {}'.format(points_control))
@@ -407,6 +447,37 @@ class Gen(BaseGen):
 
         return gid_map
 
+    def _parse_nn_map(self):
+        """Parse a nearest-neighbor spatial mapping array if lr_res_file is
+        provided (resource data is at two resolutions and the low-resolution
+        data must be mapped to the nominal-resolution data)
+
+        Returns
+        -------
+        nn_map : np.ndarray
+            Optional 1D array of nearest neighbor mappings associated with the
+            res_file to lr_res_file spatial mapping. For details on this
+            argument, see the rex.MultiResolutionResource docstring.
+        """
+        nn_map = None
+        if self.lr_res_file is not None:
+
+            handler_class = Resource
+            if '*' in self.res_file or '*' in self.lr_res_file:
+                handler_class = MultiFileResource
+
+            with handler_class(self.res_file) as hr_res:
+                with handler_class(self.lr_res_file) as lr_res:
+                    nn_d, nn_map = MultiResolutionResource.make_nn_map(hr_res,
+                                                                       lr_res)
+
+            logger.info('Made nearest neighbor mapping between nominal-'
+                        'resolution and low-resolution resource files. '
+                        'Min / mean / max dist: {:.3f} / {:.3f} / {:.3f}'
+                        .format(nn_d.min(), nn_d.mean(), nn_d.max()))
+
+        return nn_map
+
     def _parse_output_request(self, req):
         """Set the output variables requested from generation.
 
@@ -436,12 +507,12 @@ class Gen(BaseGen):
         return list(set(output_request))
 
     @classmethod
-    def reV_run(cls, tech, points, sam_configs, res_file,
+    def reV_run(cls, tech, points, sam_configs, res_file, lr_res_file=None,
                 output_request=('cf_mean',), site_data=None, curtailment=None,
                 gid_map=None, max_workers=1, sites_per_worker=None,
                 pool_size=(os.cpu_count() * 2), timeout=1800,
                 points_range=None, out_fpath=None, mem_util_lim=0.4,
-                scale_outputs=True):
+                scale_outputs=True, write_mapped_gids=False):
         """Execute a parallel reV generation run with smart data flushing.
 
         Parameters
@@ -463,6 +534,12 @@ class Gen(BaseGen):
         res_file : str
             Filepath to single resource file, multi-h5 directory,
             or /h5_dir/prefix*suffix
+        lr_res_file : str | None
+            Optional low resolution resource file that will be dynamically
+            mapped+interpolated to the nominal-resolution res_file. This
+            needs to be of the same format as resource_file, e.g. they both
+            need to be handled by the same rex Resource handler such as
+            WindResource
         output_request : list | tuple
             Output variables requested from SAM.
         site_data : str | pd.DataFrame | None
@@ -509,6 +586,9 @@ class Gen(BaseGen):
             site results are stored in memory at any given time.
         scale_outputs : bool
             Flag to scale outputs in-place immediately upon Gen returning data.
+        write_mapped_gids : bool
+            Option to write mapped gids to output meta instead of resource
+            gids.
 
         Returns
         -------
@@ -523,18 +603,22 @@ class Gen(BaseGen):
 
         # make a Gen class instance to operate with
         gen = cls(pc, res_file,
+                  lr_res_file=lr_res_file,
                   output_request=output_request,
                   site_data=site_data,
                   gid_map=gid_map,
                   out_fpath=out_fpath,
                   mem_util_lim=mem_util_lim,
-                  scale_outputs=scale_outputs)
+                  scale_outputs=scale_outputs,
+                  write_mapped_gids=write_mapped_gids)
 
         kwargs = {'tech': gen.tech,
                   'res_file': gen.res_file,
+                  'lr_res_file': gen.lr_res_file,
                   'output_request': gen.output_request,
                   'scale_outputs': scale_outputs,
                   'gid_map': gen._gid_map,
+                  'nn_map': gen._nn_map,
                   }
 
         logger.info('Running reV generation for: {}'.format(pc))
